@@ -471,7 +471,7 @@ static void stackslow(int nimages, dstrct *fileptrs, float lsig, float hsig,
     float *vdata = NULL; /* return value for cpl_image_get_data_float on error */
     float *workbuf,*workbufv,*workbufw,*workbufc,*dbuf,*wbuf,*cbuf;
     float outval,outvalc,outvalv,avlev,avvar,dx,dy,value,cval,*confwork;
-    float med,wt,w[4],renorm,*vbuf,vval,*workdatav,*workdatav2,*workdatav3;
+    float med,wt = 0.,w[4],renorm,*vbuf,vval,*workdatav,*workdatav2,*workdatav3;
     double yout,xin,yin,oxf,oyf,lra1,lra2,ldec1,ldec2;
     int *nbuf,*iloc,jout,bufloc_row,bufloc_before,iim,i,j,*outdatac;
     int gotit,iout,ixin,iyin,ind,ind1,ox,oy,bufloc,ncontrib,*lbuf,nin;
@@ -486,6 +486,7 @@ static void stackslow(int nimages, dstrct *fileptrs, float lsig, float hsig,
     outdatav = NULL; /* Remove falsepositive compiler warning */
     workdatav = NULL; /* Remove falsepositive compiler warning from freespace macro*/
     workdatav2 = NULL; /* Remove falsepositive compiler warning from freespace macro*/
+    workdatav3 = NULL; /* Remove falsepositive compiler warning from freespace macro*/
 
     /* Useful constant */
 
@@ -1100,7 +1101,7 @@ static int stack_nn(int nim, dstrct *fileptrs, float lsig, float hsig,
                     casu_fits *outvar, cpl_wcs *outwcs) {
     float *workbuf,*workbufc,*workbufw,lclip,hclip,*data,wt,med,outvalc;
     float value,*dbuf,*wbuf,*cbuf,outval,avlev,avvar,*confwork,*outdata;
-    float scale_avvar,renorm,*vbuf,*outdatav,*workbufv,*vdata,outvalv;
+    float scale_avvar,renorm,*vbuf,*outdatav,*workbufv,*vdata=NULL,outvalv;
     double oxf,oyf;
     long *iloc,i,npts,ix,iy,ind1,ind,ox,oy,nn,bufloc,ncontrib,*lbuf;
     long j,nx,ny,nz,nxo,nyo,nall;
@@ -1220,7 +1221,7 @@ static int stack_nn(int nim, dstrct *fileptrs, float lsig, float hsig,
                 bufloc = oy*nxo*nz + ox*nz + nbuf[nn];
                 value = data[ind]/(dd->expscale) + dd->skydiff;
                 workbuf[bufloc] = value;
-                if (outvar != NULL)
+                if (outvar != NULL && vdata != NULL)
                     workbufv[bufloc] = vdata[ind]/((dd->expscale)*(dd->expscale));
                 workbufw[bufloc] = wt;
                 workbufc[bufloc] = (float)cdata[ind];
@@ -1423,7 +1424,8 @@ static int stack_lin(int nim, dstrct *fileptrs, float sumweights,
     vdata = NULL; /* return value for cpl_image_get_data_float on error */
     workdatav = NULL; /* Remove falsepositive compiler warning from freespace macro*/
     workdatav2 = NULL; /* Remove falsepositive compiler warning from freespace macro*/
-
+    workdatav3 = NULL; /* Remove falsepositive compiler warning from freespace macro*/
+    outdatav = NULL;
     /* Output file info */
 
     outim = casu_fits_get_image(outfits);
@@ -2057,7 +2059,7 @@ static void backgrnd_ov(int nim, dstrct *fileptrs, int unmap) {
         /* end[0] = min((dd1->nx-1),((dd1->nx)-dx-1)); */
         /* end[1] = min((dd1->ny-1),((dd1->ny)-dy-1)); */
         nx = dd1->nx;
-        if (fabs(dx) > dd1->nx || fabs(dy) > dd1->ny) {
+        if (abs(dx) > dd1->nx || abs(dy) > dd1->ny) {
             frac = 0.0;
         } else {
             if (dx >= 0.0) {
