@@ -65,71 +65,6 @@ static int casu_mjdcompare(const cpl_frame *f1, const cpl_frame *f2);
 
 /**@{*/
 
-/*---------------------------------------------------------------------------*/
-/**
-    \brief Check existence of files in a frameset
-
-    \par Name:
-        casu_frameset_fexists
-    \par Purpose:
-        See whether the files listed in a frameset exist 
-    \par Description:
-        Loop through all the frames in a frameset. If a frame doesn't
-        exist, then send out a error message and return a bad status.
-    \par Language:
-        C
-    \param frameset
-        Input frameset 
-    \retval CASU_OK
-        If everything went OK
-    \retval CASU_FATAL
-        If any of the files in the frameset are missing
-    \author
-        Jim Lewis, CASU
- */
-/*---------------------------------------------------------------------------*/
-
-extern int casu_frameset_fexists (cpl_frameset *frameset) {
-    int nf,i,nerr;
-    cpl_frame *cur;
-    const char *fname;
-    const char *fctid = "casu_frameset_fexists";
-
-    /* Check for NULL input */
-
-    if (frameset == NULL) {
-        cpl_msg_error(fctid,"Input frameset is NULL");
-        return(CASU_FATAL);
-    }
-
-    /* Get the size of the frameset */
-
-    nf = cpl_frameset_get_size(frameset);
-    if (nf == 0) {
-        cpl_msg_error(fctid,"Input frameset has size of zero");
-        return(CASU_FATAL);
-    }
-
-    /* Loop through the frameset and see if the file is accessible */
-
-    nerr = 0;
-    for (i = 0; i < nf; i++) {
-        cur = cpl_frameset_get_position(frameset,i);
-        fname = cpl_frame_get_filename(cur);
-        if (access(fname,F_OK) != 0) {
-            cpl_msg_error(fctid,"File: %s doesn't exist",fname);
-            nerr++;
-        }
-    }
-
-    /* If there were any missing then return bad status */
-
-    if (nerr != 0)
-        return(CASU_FATAL);
-    else
-        return(CASU_OK);
-}
-
 /*---------------------------------------------------------------------------*/
 /**
     \brief Compare input tags
