@@ -39,9 +39,9 @@
 #include "hawki_distortion.h"
 #include "hawki_save.h"
 #include "hawki_load.h"
-#include "hawki_pfits.h"
-#include "hawki_utils.h"
-#include "hawki_dfs.h"
+#include "hawki_pfits_legacy.h"
+#include "hawki_utils_legacy.h"
+#include "hawki_dfs_legacy.h"
 
 /*----------------------------------------------------------------------------*/
 /**
