@@ -337,6 +337,9 @@ static int hawki_util_gendist
             for (j=0 ;j < ichip; j++)
                 hawki_distortion_delete(distortion_im[j]);
             cpl_free(distortion_im) ;
+            for (iext=0 ; iext<HAWKI_NB_DETECTORS ; iext++)
+                cpl_table_delete(distortion_table[iext]) ;
+            cpl_free(distortion_table) ;
             return -1 ;
         }
     }
