@@ -1,4 +1,6 @@
 from __future__ import with_statement
+from __future__ import absolute_import
+from __future__ import print_function
 import sys
 
 
@@ -16,7 +18,7 @@ try:
     
 except ImportError:
     import_success = False
-    print "Error importing modules pyfits, wx, matplotlib, numpy"
+    print("Error importing modules pyfits, wx, matplotlib, numpy")
 
 # Median absolute deviation function; used to scale the images
 def MAD(x):
@@ -175,8 +177,8 @@ class DataPlotterManager(object):
             self.right_opts = {'Yes':0, 'No':1}
 
             # Set the initial radio button selections (value 0 for left, 1 for right)
-            self.left_label = [key for key, value in self.left_opts.iteritems() if value == 0][0]
-            self.right_label = [key for key, value in self.right_opts.iteritems() if value == 1][0]
+            self.left_label = [key for key, value in self.left_opts.items() if value == 0][0]
+            self.right_label = [key for key, value in self.right_opts.items() if value == 1][0]
 
         else:
             # Set the plotting functions to NODATA ones
